package net.sf.doolin.context.spring;

import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;

import net.sf.doolin.context.util.StringBundles;
import net.sf.doolin.util.xml.DOMUtils;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.support.ManagedList;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;

/**
 * Parser for {@link net.sf.doolin.context.util.StringBundles}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class StringsDefinitionParser extends AbstractDefinitionParser {

	// Unique ID for the Strings definitions
	private static final AtomicInteger idGenerator = new AtomicInteger(0);

	@Override
	public void doParse(Element element, ParserContext parserContext,
			BeanDefinitionBuilder builder) {
		// List of string bundles
		@SuppressWarnings("unchecked")
		List<String> pathList = new ManagedList();
		List<Element> stringBundleList = DOMUtils.getElements(element,
				ContextElements.STRING_BUNDLE);
		for (Element eStringBundle : stringBundleList) {
			String path = DOMUtils.getText(eStringBundle);
			path = StringUtils.trim(path);
			pathList.add(path);
		}
		builder.addPropertyValue("paths", pathList);
		// ID
		String id = DOMUtils.getAttribute(element, "id", null);
		if (StringUtils.isBlank(id)) {
			element.setAttribute("id", "StringBundles#"
					+ idGenerator.incrementAndGet());
		}
		// OK
		super.doParse(element, parserContext, builder);
	}

	@Override
	protected Class<StringBundles> getBeanClass(Element element) {
		return StringBundles.class;
	}

}
